/* $Id: W3NNTP.h 276 2024-04-07 10:12:10Z nishi $ */
/* --- START LICENSE --- */
/* -------------------------------------------------------------------------- */
/*                                                  The WWW Library - LibW3   */
/*                                                  developed by Nishi        */
/*                                                  http://nishi.boats/libw3  */
/* -------------------------------------------------------------------------- */
/* Copyright (c) 2024 Nishi.                                                  */
/* Redistribution and use in source and binary forms, with or without modific */
/* ation, are permitted provided that the following conditions are met:       */
/*     1. Redistributions of source code must retain the above copyright noti */
/* ce, this list of conditions and the following disclaimer.                  */
/*     2. Redistributions in binary form must reproduce the above copyright n */
/* otice, this list of conditions and the following disclaimer in the documen */
/* tation and/or other materials provided with the distribution.              */
/*     3. Neither the name of the copyright holder nor the names of its contr */
/* ibutors may be used to endorse or promote products derived from this softw */
/* are without specific prior written permission.                             */
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS */
/* " AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, TH */
/* E IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPO */
/* SE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS  */
/* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CON */
/* SEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITU */
/* TE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPT */
/* ION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, S */
/* TRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN AN */
/* Y WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY  */
/* OF SUCH DAMAGE.                                                            */
/* -------------------------------------------------------------------------- */
/* --- END LICENSE --- */

#ifndef __W3NNTP_H__
#define __W3NNTP_H__

/**
 * @file W3NNTP.h
 * @~english
 * @brief NNTP part of LibW3
 *
 * @~japanese
 * @brief LibW3のNNTP処理部分
 *
 */

#ifdef __cplusplus
extern "C" {
#endif

#include "W3Core.h"

void __W3_NNTP_Request(struct W3* w3);

/**
 * @~english
 * @brief Sends the NNTP command.
 * @param w3 Pointer to the struct
 * @note This function is different with W3_Send_Request!
 * @note When W3_Send_Request just handshakes, this function sends the NNTP command!
 *
 * @~japanese
 * @brief NNTPのコマンドを送ります。
 * @param w3 構造体へのポインター
 * @note この関数は W3_Send_Request とは違います！
 * @note W3_Send_Request は単純にハンドシェイクするだけですが、この関数はFTPのコマンドを送ります！
 *
 */
void W3_NNTP_Send_Request(struct W3* w3);

/**
 * @~english
 * @brief Disconnects from the NNTP.
 * @param w3 Pointer to the struct
 *
 * @~japanese
 * @brief NNTPから切断します。
 * @param w3 構造体へのポインター
 *
 */
void W3_NNTP_Disconnect(struct W3* w3);

#ifdef __cplusplus
}
#endif

#endif
